flex_drop_down_menu library

Classes

CustomDropdownMenu<T>
A dropdown menu that can be opened from a TextField. The selected menu item is displayed in that field.
FlexDropdownMenuEntry<T>
Defines a FlexDropdownMenu menu button that represents one item view in the menu.

Typedefs

FilterCallback<T> = List<FlexDropdownMenuEntry<T>> Function(List<FlexDropdownMenuEntry<T>> entries, String filter)
A callback function that returns the list of the items that matches the current applied filter.
SearchCallback<T> = int? Function(List<FlexDropdownMenuEntry<T>> entries, String query)
A callback function that returns the index of the item that matches the current contents of a text field.