scrollToHighlightAlignment property

double scrollToHighlightAlignment
final

The alignment of the highlighted item in the menu. defaults to 0.9, which means the highlighted item will be aligned to the bottom of the menu.

Implementation

final double scrollToHighlightAlignment;