value property
T
value
final
the value used to identify the entry.
This value must be unique across all entries in a FlexDropdownMenu.
Implementation
final T value;
the value used to identify the entry.
This value must be unique across all entries in a FlexDropdownMenu.
final T value;