CustomPaginatedDropdown class

Inheritance

Constructors

CustomPaginatedDropdown({Key? key, required List<String> items, required VoidCallback onLoadMore, ValueChanged<String>? onItemSelected, bool isLoading = false, double itemHeight = 48.0, double maxHeight = 300.0, double width = 300.0, double maxWidth = 500.0, InputDecoration? inputDecoration, TextStyle? highlightTextStyle, Color? highlightColor, Duration scrollAnimationDuration = const Duration(milliseconds: 100), Curve scrollAnimationCurve = Curves.easeInOut, double keyRepeatDelayMs = 200, TextStyle? textStyle, String? preselectedItem, bool enabled = true, bool caseSensitive = false})
const

Properties

caseSensitive bool
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
final
highlightTextStyle TextStyle?
final
inputDecoration InputDecoration?
final
isLoading bool
final
itemHeight double
final
items List<String>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyRepeatDelayMs double
final
maxHeight double
final
maxWidth double
final
onItemSelected ValueChanged<String>?
final
onLoadMore VoidCallback
final
preselectedItem String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollAnimationCurve Curve
final
scrollAnimationDuration Duration
final
textStyle TextStyle?
final
width double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomPaginatedDropdown>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited