flex_drop_down_menu library
Classes
-
CustomDropdownMenu<
T> - A dropdown menu that can be opened from a TextField. The selected menu item is displayed in that field.
-
FlexDropdownMenuEntry<
T> -
Defines a
FlexDropdownMenumenu button that represents one item view in the menu.
Typedefs
-
FilterCallback<
T> = List< FlexDropdownMenuEntry< Function(List<T> >FlexDropdownMenuEntry< entries, String filter)T> > - A callback function that returns the list of the items that matches the current applied filter.
-
SearchCallback<
T> = int? Function(List< FlexDropdownMenuEntry< entries, String query)T> > - A callback function that returns the index of the item that matches the current contents of a text field.