labelWidget property
Overrides the default label widget which is Text(label).
{@tool dartpad} This sample shows how to override the default label Text widget with one that forces the menu entry to appear on one line by specifying Text.maxLines and Text.overflow.
** See code in examples/api/lib/material/dropdown_menu/dropdown_menu_entry_label_widget.0.dart ** {@end-tool}
Implementation
final Widget? labelWidget;